-- selon PLAN COMPTABLE MINIMUM NORMALISE BELGE
-- contribu par Jens-Ingo Brodesser, jens-ingo@all2all.org, Moving Art Studio ASBL, ALL2ALL The Independent Network
-- le 15/07/2003

INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('500','Action propres - Eigen aandelen','A','Q','','50');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('50','Actions propres - Eigen aandelen','H','Q','','50');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('756000','Produits financiers divers','A','I','AR_paid:AP_paid','75');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612200','Carburants voitures','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('630','Dotations amort., rduction valeur s/immo. - Afschr., waardeverm. op v. a., toevoeging','A','E','','63');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613210','Honoraires avocats','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('712','Des encours de fabrication - In de vooraad goederen in bewerking','A','I','IC_sale','71');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('600','Achats matires premires - Aankopen van grondstoffen','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('614400','Entre aux foires','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('742','Plus-values crances com. - Meerwaarden realis. handelsvorderingen','A','I','','74');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613304','Traiteurs-rception clientle','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('64','Autres charges exploitation - Andere bedrijfskosten','H','E','','64');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('76','Produits exceptionnels - Uitzonderlijke opbrengsten','H','I','','76');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('743000','Ventes diverses - Diverse bedrijfsopbrengsten','A','I','','74');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('760100','sur immobilisations corp. - op materile vaste activa','A','I','','760');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('611150','Charges locatives voitures','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('771200','Reprises de provisions fiscales - Terugn. fiscale voorz.','A','I','','771');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('794','Intervention associ perte - Tussenkomst vennoten verlies','A','I','','79');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('404','Produits  recevoir - Te innen opbrengsten','A','A','','40');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('406','Acomptes verss - Vooruitbetalingen','A','A','','40');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('407','Crances douteuses - Dubieuze debiteuren','A','A','','40');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411620','TVA  rgulariser (case 62)','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('41','Autres crances - Overige vorderingen','H','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('442001','Fournisseurs essence','A','L','AP','44');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('608','Remises ristournes rabais obtenus - Ontvangen kortingen ristorno''s en rabatten (-)','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('609000','de matires premires - van grondstofen','A','E','','609');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('6','CLASSE 6 -- CHARGES - KOSTEN','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612140','Internet','A','I','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('655000','Ecarts de conversion de devises','A','E','AR_paid:IC_sale:IC_expense','65');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411590','TVA ACHATS 6%','A','A','AP_tax:IC_taxpart:IC_taxservice','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411591','TVA ACHATS 21%','A','A','AP_tax:IC_taxpart:IC_taxservice','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411','TVA A RECUPERER - TERUG TE VORDEREN BTW','H','I','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('44','Dettes commerciales - Handelsschulden','H','L','','44');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('416','Crances diverses - Diverse vorderingen','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('409','Rductions de valeur actes (-) - Geboekte waardevermindering','A','A','','40');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451541','TVA DUE VENTES 21%','A','L','AR_tax:IC_taxpart:IC_taxservice','451');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451540','TVA DUE VENTES 6%','A','L','AR_tax:IC_taxpart:IC_taxservice','451');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451560','TVA DUE CO-CONTRACTANT','A','L','AR_tax','451');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('640','Charges fiscales de l''exploitation - Bedrijfsbelastingen','A','E','','64');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('713','Des Produits finis - In de voorraad gereed product','A','I','IC_sale','71');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('750','Produits immo. financires - Opbrengsten financile vaste activa','A','I','','75');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('656100','Frais de banque','A','E','','65');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('755000','Ecarts de convers. devises - Resultats omrekening vreemde valuta','A','I','IC_sale:IC_income','75');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('754000','Diffrence de change - Wisselresultaten','A','I','AR_amount:IC_income','75');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('761','Reprises rduct. valeur immo. fin. - Terugneming waardeverm. fin. v. a.','A','I','','76');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('773','Impts trangers s/rsultat - Buitenl. belasting op resultaat','A','I','','77');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('75','Produits financiers - Financile opbrengsten','H','I','','75');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('77','Rgularisation d''impts, reprises provisions fiscales - Regul. belastingen en terugneming fiscale voorz.','H','I','','77');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('7','CLASSE 7 -- PRODUITS - OPBRENGSTEN','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('440','Fournisseurs - Leveranciers','A','L','AP','44');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612300','Abonnements & Documentations','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('410','Capital appel, non vers - Opgevraagd, niet-gestort kapitaal','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('417','Crances douteuses - Dubieuze debiteuren','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4500','4500-4504 Impts belges rsultat - Belgische winstbelasting','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451','TVA A PAYER - TE BETALEN BTW','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4525','4525-4527 Autres impts et taxes belges - Andere Belg. belast. en taksen','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('455','Rmunerations - Bezoldigingen','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('601','Achat des fournitures - Aankoop van hulpstoffen','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('49','Comptes de rgularisation - Overlopende- en wachtrekeningen','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613220','Honoraires notaires','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('414100','Indeminits s/sinistres  recevoir - Te ontvang. schadevergoed.','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('42','Dettes  plus d''un an cheant dans l''anne - Schulden op meer dan n jaar die binnen het jaar verfallen','H','L','','42');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613311','Deplacements tranger train, taxi, etc','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('611151','Charges locatives camions/camionnettes','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('432','Etabli. crdit, crdits d''acceptation - Acceptkrediten','A','L','','43');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('433','Etabl. crdit, dettes cpt. courant - Schulden rekening courant','A','L','','43');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('705100','DNS REGISTRY','A','I','AR_amount:IC_income','70');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411640','TVA  recuprer s/NDC mises','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('52','Titres  revenu fixe - Vastrentende Effecten','H','Q','','52');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('609100','de fourniture - van hulpstoffen','A','E','','609');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('442004','VISA - dcompte mensuel','A','L','AP_amount:AP_paid','44');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('65','Charges financires','H','E','','65');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('442002','Fournisseurs restaurants','A','L','AP','44');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('499000','Compte d''attente - Wachtrekening','A','Q','AR_amount:AP_amount:IC_sale:IC_income:IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('656500','Inttts retards sociaux - Sociale achterst. interest','A','E','AP_amount:IC_expense','65');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('617','Personnel intrimaire - Uitzendkrachten','A','E','','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('618','Divers','A','E','','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('620','Rmunerations et avant. sociaux directs - Bezolgingen en rechts. sociale voordelen','A','E','','62');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('620000','Administrateurs ou grants - Bestuurders of zaakvoerders','A','E','','620');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('620100','Personnel de direction - Directiepersoneel','A','E','','620');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('602','Achats services, travaux, tudes - Aankopen diensten, werk, studies','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612143','Noms DNS','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612000','Eau','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('442005','AMERICAN EXPRESS - dcompte mensuel','A','L','AP','44');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('641','Moins-values s/ralis. cour. d''immo. corp. - Minderwa. courante realis. vaste activa','A','E','','64');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('715','Des immeubles constr. dest.  la vente - In de voorr. onroe. goederen best. v. verkoop','A','I','IC_sale','71');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612400','Imprims & fournitures de bureau','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('414200','Subsides en capital  recevoir - Te ontv. kapitaalsubsidies','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('66','Charges exceptionnelles','H','E','','66');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613230','Honoraires huissiers de justice','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613313','Restaurants tranger','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('74','Autres produits exploitation - Andere bedrijfsopbrengsten','H','I','','74');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('610','Loyers et charges locatives','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('751','Produits actifs circulants - Opbrengsten uit vlottende activa','A','I','','75');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('705200','WEB HOSTING','A','I','AR_amount:IC_income','70');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('705300','INTERVENTION','A','I','AR_amount:IC_income','70');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('762','Reprises provisions risq. charg. except. - Terugn. voorz. uitz. risico en kosten','A','I','','76');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('780','Prlvements s/impts diffrs - Onttrekking a. uitgesteld. belast.','A','I','','78');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('78','Prlvements rserves immunises et impts diffrs - Onttrek. belast.vrije reserves en de uitgestelde belastingen','H','I','','78');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('70','Chiffre d''affaires - Omzet','H','I','','70');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('614100','Catalogues et imprimes','A','I','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('53','Dpts  terme - Termijndeposito''s','H','Q','','53');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('609400','de marchandises - van handelsgoederen','A','E','','609');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451501','TVA DUE ACHATS INCO 21%','A','L','AR_tax:IC_taxpart:IC_taxservice','451');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612010','Chauffage','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612410','Fournitures informatiques','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613250','Honoraires scretariat social','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613400','Seminaires & Recyclages','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411593','TVA DUE 1ER TRIMESTRE TOTAL','A','L','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612530','Petit outillage & petit matriel','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('230010','Inst. techniques acquis. exercice - Installaties m.b.t. dit boekj.','A','A','AP_amount:IC_sale','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612540','Petit matriel informatique','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('603','Sous-traitances gnrales - Algemene onderaanemingen','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('743200','COTISATION DE MEMBRE','A','I','AR_amount:IC_income','74');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411000','Cpt. curr. TVA  rcuperer - Terug te vord. BTW: saldo BTW r/c','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('601000','Emballages perdus','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('416200','Cpt. courant associs - Rekening-courant vennoten','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('56','Office des chques postaux - Postchque en girodienst','H','Q','','56');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('67','Impt sur le rsultat','H','E','','67');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('609500','d''immeubles achts destins  vente - van gek. onroer. goederen best. v. verkoop','A','E','','609');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('654','Diffrence de change','A','E','AP_amount','65');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('642','Moins-values s/ralis. crances com. - Minderwa. realis. handelsvorderingen','A','E','','64');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('717','Des commandes en cours excution - In de bestelling in uitvoering','A','I','IC_sale','71');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('752','Plus-values ralis. d''actifs circulants - Meerwaar. realis. v. vlottende activa','A','I','','75');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('763','Plus-values s/ralis. actifs immo. - Meerwaar. realis. vaste a.','A','I','','76');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('789','Prlvements s/rserves immunises - Onttrekking a. belast.vrije reserves','A','I','','78');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('79','Affectations et prlvements - Resultaatverwerking','H','I','','79');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('412','Impts, prcomptes  rcuprer - Terug te vorderen belast. en voorheffingen','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('418','Cautionnements verss en numraire - Borgtochten betaald in contanten','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('120','Plus-values de rvaluation sur immo. incorp. - Herwaarderingsmeerwaarde','A','L','','12');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('121','Plus-values de rvaluation sur immo. corp. - Herwaarderingsmeerwaarde','A','L','','12');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('122','Plus-values de rvaluation sur immo. financiers - Herwaarderingsmeerwaarde','A','L','','12');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('123','Plus-values de rvaluation sur stocks - Herwaarderingsmeerwaarde','A','L','','12');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('124','Reprises de rduction de valeur sur placements trsorerie - Herwaarderingsmeerwaarde','A','L','','12');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('12','Plus-values de rvaluation - Herwaarderingsmeerwaarde','H','L','','12');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('110','Primes d''mission - Uitgiftepremies','A','L','','11');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('11','Primes d''mission - Uitgiftepremies','H','L','','11');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('643','643-648 Charges d''exploitation diverses - Diverse berijfskosten','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612100','Telephone','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('10','Capital - Kapitaal','H','L','','10');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1','CLASSE 1 -- CAPITAL PROPRE, ... - EIGEN VERMOGEN, ...','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('60','Approv. et marchandises','H','E','','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('717000','Valeur d''acquisition - Aanschaffingswaarde','A','I','','717');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('68','Transferts comptes immunises et impts diffrs','H','E','','68');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('130','Rserve lgale - Wettelijke reserve','A','L','','13');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('131100','Autres rserves indisponibles - Andere onbeschikbare reserves','A','L','','13');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('132','Rserves immunises - Belastingvrije reserves','A','L','','13');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('131000','Rserves pour actions propres - Reserve voor eigen aandelen','A','L','','13');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('133','Rserves disponibles - Beschikbare reserves','A','L','','13');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('101','Capital non appel (-) - Niet opgevraagd kapitaal (-)','A','L','','10');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('14','Bnfice/perte report(e) - Overgedragen winst/verlies','H','L','','14');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('100','Capital souscrit - Geplaatst kapitaal','A','L','','10');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('601010','Emballages recuperables','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('140','Bnfice/perte report(e) - Overgedragen winst/verlies','A','L','','14');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('620200','Employs - Bedienden','A','E','','620');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('15','Subsides en capital - Kapitaalsubsidies','H','L','','15');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('700','700-707 Ventes et prestations de services - Verkopen en dienstprestaties','H','E','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612450','Photocopies-Photographies','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('131','Rserves indisponibles - Onbeschikbare reserves','A','L','','13');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('16','Provisions et impts diffrs - Voorz. en uitgestelde belastingen','H','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('160','Provisions pensions et obligations - Voorz. pensioenen en soortg. verplichtingen','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('161','Provisions charges fiscales - Voorz. belastingen','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('162','Provisions gros entretiens et rparations - Voorz. grote herstel/onderh.','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('163','Provisions autres risques-charges - Voorzieningen voor Lijfrente','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('753','Subsides en capital et intrts - Kapitaal- en interestsubsidies','A','I','','75');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('705000','Prestations de services - Verkopen en dienstprestaties','A','I','','70');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('764','764-769 Autres produits execptionnels - Andere uitz. opbrengsten','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('790','Bnfice report exercice prcd. - Overgedragen winst vorige boekj.','A','I','','79');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('168200','Impts diff. s/+value immo. corp. - Uitg. belast./meerwa./mat. v.a.','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('604','Achats marchandises - Aankopen van handelsgoederen','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('43','Dettes financires - Financile schulden','H','L','','43');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('168000','Impts diff. s/subsides en capital - Uitgest. belast./Kapitaalsubsidie','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613265','Honoraires d''autres','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('620800','Assurance revenus garantis','A','E','AP_amount:IC_expense','62');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('168800','Impts diffrs trangers - Uitg. belast. buitenland','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('17','Dettes  plus d''un an - Schulden op meer dan een jaar','H','L','','17');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('150','Montants obtenus - Kapitaalsubsidies','A','L','','15');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('172000','Dettes location fin. et assimiles - Leasingschuld. van vaste activa','A','L','','17');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('419','Rductions de valeur actes (-) - Geboekte waardevermindering (-)','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4505','4505-4507 Autres impts et taxes belges - Andere Belg. belast. en taksen','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451610','TVA  rgulariser (case 61)','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4528','Impts et taxes trangers - Buitenlandse belast. en taksen','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('456','Pcules de vacances - Vakantiegeld','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('176','Acomptes reus sur commandes','A','L','','17');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('47','Dettes affectation rsultat - Schulden besteming resultaat','H','L','','47');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('231010','Mach. et gros mat. acquis. exercice - Machines m.b.t. dit boekj.','A','A','AP_amount:IC_sale','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('178','Cautionnements reu en numraire - Borgtocht. ontvang. in contanten','A','L','','17');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('179','Dettes diverses - Overige schulden','A','L','','17');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('174','Autres emprunts - Overige schulden','A','L','','17');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2','CLASSE 2 -- FRAIS D''ETABLISSEMENT, ACTIFS IMMOBILISES, ... - OPRICHTINGSKOSTEN, VASTE ACTIVA, ...','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('20','Frais d''tablissement - Oprichtingskosten','H','A','','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('200','Frais de constitution - Kosten van oprichting','A','A','','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('200000','Fr. const. acquis. anterieurs - Kost. opricht./kapitaalverhoging','A','A','','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('605','Achats d''immeubles destins vente - Aankopen onroer. goederen bestemd v. verkoop','A','E','IC_cogs','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('61','Services et biens divers','H','E','','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('69','Affectations et prlvements','H','E','','69');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('200900','Fr. const. amort. anterieur - Afschr. kost. opricht./kap.verh. vorig','A','A','','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('200910','Fr. const. amort. de l''exercice - Afschr. kost. opricht./kap.verh. dit','A','A','','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411594','TVA DUE 2E TRIMESTRE TOTAL','A','L','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('202','Autres frais d''tablissement - Overige oprichtingskosten','A','A','','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('204','Frais de restructuration - Herstructureringskosten','A','A','','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('201','Frais d''mission d''emprunts - Kosten bij uitgifte van leningen','A','A','','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('21','Immobilisations incorporelles - Immateriele vaste activa','H','A','','21');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('620300','Ouvriers - Arbeiders','A','E','','620');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('211','Concessions, brevets, licences, ... - Consessies, octrooien, licenties, ...','A','A','','21');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('210','Frais de recherches et developpement - Kosten van onderzoek en ontwikkeling','A','A','','21');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('212','Goodwill','A','A','','21');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('213','Acomptes verss - Vooruitbetalingen','A','A','','21');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('214','Surprix affrents acquisition d''une participation','A','A','','21');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('22','Terrains et constructions - Terreinen en gebouwen','H','A','','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('743','743-749 Produits d''exploitation divers - Diverse bedrijfsopbrengsten','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612020','Electricit','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('221','Constructions - Gebouwen','A','A','','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('717100','Bnfice pris en compte - Toegerekende winst','A','I','','717');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('756','756-759 Produits financiers divers - Diverse financile opbrengsten','H','I','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('222','Terrains btis - Bebouwde terreinen','A','A','','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('13','Rserves - Reserves','H','L','','13');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('223','Autres droits rels sur immeubles - Overige zakelijke rechten op onroe.','A','A','','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('221000','Constructions acquis. anterieurs - Geb. aanschaffingsprijs vorig. boekj.','A','A','','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('240210','Matriel informatique acquis. exercice - Hardware','A','A','AP_amount','24');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('221900','Constructions amort. anterieurs - Afschr. op gebouwen vorig boekj.','A','A','','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('221910','Constructions amort. de l''exercice - Afschr. op gebouwen dit boekj.','A','A','','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('771','Impts belges sur le rsultat - Belgische belasting op het resultaat','A','I','','77');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('23','Installations, machines et outillage - Installaties, machines en uitrusting','H','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('230','Installations - Installaties','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('230000','Inst. techniques acquis. anterieurs - Installaties m.b.t. vorig boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('230900','Inst. techniques amort. anterieurs - Afschr. op installaties vorig boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('230910','Inst. techniques amort. exercice - Afschr. op installaties dit boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('231','Machines','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('791','Prlvement s/capital et primes missions - Onttrek. kapitaal e. uitgiftepre.','A','I','','79');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('220','Terrains - Terreinen','A','A','','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('237','Outillage - Uitrusting','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('231000','Mach. et gros mat. acquis anterieurs - Machines m.b.t. vorig boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613100','Assurance incendie','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('231900','Mach. et gros mat. amort. anterieurs - Afschr. op machines vorig boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('231910','Mach. et gros mat. amort. exercice - Afschr. op machines dit boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613275','Publications lgales','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('237900','Outillage amort. anterieurs - Afschr. op uitrusting vorig boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451570','TVA DUE SUR IMPORTATIONS','A','L','AR_tax','451');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('237910','Outillage amort. exercice - Afschr. op uitrusting dit boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('237000','Outillage acquis. anterieurs - Uitrusting m.b.t. vorig boekj.','A','A','','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('580000','TRANSFERTS INTERNES DES FONDS - TRANSFERTEN','A','Q','AR_paid:AP_paid','58');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('24','Mobilier et matriel roulant - Meubilair en rollend materieel','H','A','','24');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2400','Mobilier - Meubilair','A','A','','24');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2401','Matriel de bureau - Bureaumaterieel','A','A','','24');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2402','Matriel informatique - Hardware','A','A','','24');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('241','Voiture - Rollend materieel (wagen)','A','A','','24');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('62','Rmunrations, charges sociales et pensions','H','E','','62');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('25','Immobilis. en loc-financement - Vaste activa in leasing of op grond','H','A','','25');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612120','GSM','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('242','Camions - Rollend materieel (vrachtwagen)','A','A','','24');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('250','Terreins loc-fin - Terreinen in leasing','A','A','','25');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('251','Install., machines loc-fin - Installaties, machines in leasing','A','A','','25');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('309','Rduction val. act. mat. premires (-) - Geboekte waardev. grondst. (-)','A','A','','30');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('253','Matriel en loc-fin - Uitrusting in leasing','A','A','','25');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('254','Mat. inform. en loc-fin- Hardware in leasing','A','A','','25');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('255','Mat. roulant en loc-fin - Rollend materieel leasing','A','A','','25');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('26','Autres immobilisations corp. - Andere materiele vaste activa','H','A','','26');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('260','Amenagement locaux lous - Inrichtingskost. gehuurde gebouw','A','A','','26');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613130','Assurance crdit','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('300','Approv. matire premire - Grondstoffen','A','A','IC','30');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411595','TVA DUE 3E TRIMESTRE TOTAL','A','L','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('620400','Autres membres du personnel - Andere personeelsleden','A','E','','620');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('270','Immo. corp. en cours et acomptes verss - V. activa in aanbouw en vooruit','A','A','','27');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613300','Deplacements Belg. train, taxi, etc','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('27','Immo. corp. en cours et acomptes verss - V. activa in aanbouw en vooruit','H','A','','27');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('252','Mobilier en loc-fin - Meubilair in leasing','A','A','','25');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('168100','Impts diff. s/+value immo. incorp. - Uitg. belast./meerwa./immat. v.a.','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('168700','Impts diff. s/+value fonds publ. belges - Uitg. bel./meerwa./belg. effecten','A','L','','16');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('28','Immobilisations financiers - Financiele vaste activa','H','A','','28');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451630','TVA sur NDC reues','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('649','Ch. exploit. portes actif c. frais de restruct. (-) - Als herstruct.kost. geactiv. bedrijfsk. (-)','A','E','','64');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('71','Variation stocks et commandes en cours - Wijzigingen vorraden en in de bestellingen in uitvoering','H','I','','71');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('740','Subsides et montants compensat. - Subsidies en compens. bedragen','A','I','','74');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('760','Reprises amort. et rduct. valeur - Terugneming afschr. en waardeverm.','A','E','','76');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('280','Participations entreprises lies - Aanschaffingsw. deeln. verb. ond.','A','A','','28');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('771000','Rgularisations impts dus verss - Regularisiering versch. of betaal. belast.','A','I','','771');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('281','Crances s/entreprises lies - Vorderingen op rekening','A','A','','28');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('283','Crances s/entr. avec lien de part.','A','A','','28');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('284','Autres actions et parts - Aanschaffingsw. and. aand.','A','A','','28');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('285','Autres crances -  Overige vorderingen','A','A','','28');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('288','Cautions verss en numeraire - Borgtocht. betaald in contanten','A','A','','28');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('792','Prlvements rserves - Onttrekking reserves','A','I','','79');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('173100','Promesses banque - Promessen bank','A','L','','17');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('290','Crances commerciales - Commerciele vorderingen','A','A','','29');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('441','Effets  payer - Te betalen wissels','A','L','','44');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('430','Emprunts en compte  terme fixe - Leningen op rekeningen vaste termijn','A','L','','43');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('237010','Outillage acquisition exercice - Uitrusting m.b.t. dit boekj.','A','A','AP_amount:IC_sale','23');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('29','Crances  plus d''un an - Vorderingen op meer dan een jaar','H','A','','29');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('45','Dettes fiscales, salariales, sociales - Schulden m. betrekking tot belastingen, bezoldingen en sociale lasten','H','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('452','Impts et taxes  payer','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('290000','Clients > 1 an - Handelsdebiteuren > 1 jaar','A','A','','29');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('290100','Effects  recevoir >1 an - Te innen wissels > 1 jaar','A','A','','29');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('290600','Acptes verss s/immo. financ. > 1 an - Vooruitbetalingen > 1 jaar','A','A','','29');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('290700','Crances douteuses - Dubieuze debiteuren >1 jaar','A','A','','29');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('290900','Rduction valeur acte cr.dout. - Geboekte waardevermindering (-)','A','A','','29');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('291','Autres Crances > 1 an - Over. vorderingen op rekening > 1 j.','A','A','','29');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('30','Approv. matires premires - Grondstoffen','H','A','','30');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3','CLASSE 3 -- STOCK ET COMMANDES EN COURS - GRONDSTOFFEN','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('453','Prcompte retenus - Ingehouden voorheffingen','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('459','Autres dettes sociales - Andere sociale schulden','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('48','Dettes diverses - Diverse schulder','H','L','','48');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('31','Approv. et fournitures - Hulpstoffen','H','A','','31');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('431','Etabli. crdit, promesses - Kreditinstellingen, promessen','A','L','','43');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('400','Clients - Handelsdebiteuren','A','A','AR','40');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('319','Rduction valeur actes (-) - Geboekte waardev. hulpstoffen (-)','A','A','','31');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('32','Encours de fabrication - Goederen in bewerking','H','A','','32');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('708','Remis. rabais ristourn. accords (-) - Toegek. korting. ristorno''s rabat. (-) ','A','I','AR_amount:IC_expense','70');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('741','Plus-values ralis. cour. immo. corp. -  Meerwaar. cour. realis. materile v.a.','A','I','','74');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('33','Produits finis - Gereed Product','H','A','','33');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('72','Production immobilise - Geproduceerde vaste activa','H','I','','72');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('656600','Intrts rtards com. - Com. achterst. interest','A','E','AP_amount:IC_expense','65');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('34','Marchandises - Handelsgoederen','H','A','','34');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('411596','TVA DUE 4E TRIMESTRE TOTAL','A','L','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('760000','sur immobilisations incorp. - op immaterile vaste activa','A','I','','760');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('35','Immeubles destins vente - Onroerende goederen bestemd. v. verk.','H','A','','35');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('771100','Rgul. d''impts estims - Regul. geraamde belasting','A','I','','771');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('793','Perte  reporter - Over te dragen verlies','A','I','','79');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4','CLASSE 4 -- CREANCES ET DETTES A UN AN AU PLUS - VORDERINGEN EN SCHULDEN OP TEN HOOGTE EEN JAAR','H','A','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5','CLASSE 5 -- PLACEMENTS DE TRESORIERIE - LIQUIDE MIDDELEN / GELDBELEGGINGEN','H','Q','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('40','Crances commerciales - Handelsvorderingen','H','I','','40');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('540','Chques  encaisser - Te incasseren chques','A','Q','AR_paid:AP_paid','54');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('329','Rduction valuer acte (-) - Geboekte waardeverminderingen (-) ','A','A','','32');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('339','Rductions de valeur actes (-) - Geboekte waardeverminderingen (-) ','A','A','','33');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('340','Marchandises - Handelsgoederen','A','A','IC','34');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('51','Actions et parts - Aandelen','H','Q','','51');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('349','Rduct. valeur actes (-) - Geboekte waardeverminderingen (-) ','A','A','','34');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('359','Rductions valeur actes (-) - Geboekte waardeverminderingen (-) ','A','A','','35');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613150','Assurance tous risques matriel lec.','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('552000','KBC56','A','Q','AR_paid:AP_paid','55');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('58','Virements interns - Interne overboekingen','H','Q','','58');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('55','Banque - Rekening-courant','H','Q','','55');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('54','Valeurs chues  encaissement -  Te incasseren verfallen waarden','H','Q','','54');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('57','Caisses - Kassen','H','Q','','57');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('63','Amortissements, rductions valeur, provisions risques et charges','H','E','','63');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613303','Restaurants','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('310','Valeur d''acquisition - Aanschaffingswaarde hulpstoffen','A','A','IC','31');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('320','Valeur d''acquisition - Aanschaffingsw. goed. bewerking','A','A','IC','32');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('330','Produits finis - Gereed product','A','A','IC','33');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('350','Immeubles - Aanschaffingsw. onr. goed. verkoop','A','A','IC','35');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('705700','HARDWARE','A','I','AR_amount:IC_sale','70');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('609','Variation de stock - Voorraadwijzigingen','A','E','','60');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('621','Cotisation patronales d''assur. sociales - Werkgeversbijdragen soc. verzekeringen','A','E','','62');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451640','TVA  recuprer s/NDC mises','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('454','O.N.S.S. - R.S.Z.','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('511','Montants non-appels (-) - Niet opgevraagde bedragen aan. (-)','A','Q','','51');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('640700','TVA non-deductible','A','E','AP_tax:IC_taxpart:IC_taxservice','64');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('221010','Construction acquis. de l''exercice - Geb. aanschaffingsprijs dit boekj.','A','A','AP_amount:IC_sale','22');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('401','Effets  recevoir - Te innen wissels','A','A','','40');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('444','Factures  recevoir - Te ontvangen facturen','A','L','','44');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('519','Rduct. valeur actes (-) - Geb. waardev. aandelen (-)','A','Q','','51');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('570000','CAISSE ESPECES - CONTANTEN','A','Q','AR_paid:AP_paid','57');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('414','Produits  recevoir - Te innen opbrengsten','A','A','','41');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451000','COMPTE COURANT TVA DUE','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('450','Dettes fiscales estimes - Geramd bedrag der belastingschulden','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4520','4520-4524 Impts belges rsultat - Belgische winstbelastingen','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4508','Impts et taxes trangers - Buitenlandse belast. en taksen','H','L','','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('46','Acomptes reus sur commandes','H','L','','46');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('510','Valeur d''acquisition - Aanschaffingswaarde','A','Q','','51');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('499100','Compte de repartition - Verdelingsrekening','A','L','AR_paid:AP_paid:IC_income:IC_expense','');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('613180','Assurance RC professionnelle','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('452500','Prcompte immobilier - Onroerende voorhoeffing','A','L','','45');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('611340','Entretiens & rparations locaux','A','E','AP_amount:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('612150','Frais postaux','A','E','AP_amount:IC_cogs:IC_expense','61');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('200010','Fr. const. acquis. de l''exercice - Kost. opricht./kap.verh. dit boekjaar','A','A','AP_amount','20');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('451500','TVA DUE ACHATS INCO 6%','A','A','AR_tax:IC_taxpart:IC_taxservice','451');

INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '411590'),0.06,'BE ... ... ...');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '411591'),0.21,'BE ... ... ...');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '451500'),0.06,'BE ... ... ...');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '451501'),0.21,'BE ... ... ...');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '451540'),0.06,'BE ... ... ...');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '451541'),0.21,'BE ... ... ...');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '640700'),0.21,'BE ... ... ...');

UPDATE defaults SET inventory_accno_id = (SELECT id FROM chart WHERE accno = '340'), income_accno_id = (SELECT id FROM chart WHERE accno = '499000'), expense_accno_id = (SELECT id FROM chart WHERE accno = '499000'), fxgain_accno_id = (SELECT id FROM chart WHERE accno = '755000'), fxloss_accno_id = (SELECT id FROM chart WHERE accno = '655000'), weightunit = 'kg', curr = 'EUR:USD';
